@@ -23,7 +23,13 @@ class TestEvent(object):
         d = {}
 
         d["test_name"] = self.TestName
-        d["notes"] = self.Notes
+        d["notes"] = {}
+
+        for key in self.Notes.keys():
+            d["notes"][key] = [str(e) for e in self.Notes[key]]
+            print([str(e) for e in self.Notes[key]])
+
+
         d["start"] = str(self.Start)
         d["end"] = str(self.End)
         d["duration"] = str(self.EventDurationSeconds)
